@@ -53,8 +53,7 @@
 #define d(x)
 
 struct _CamelMapiStorePrivate {
-	EMapiConnection *connection;
-	GStaticRecMutex connection_lock;
+	EMapiConnection *conn;
 
 	GHashTable *id_hash; /*get names from ids*/
 	GHashTable *name_hash;/*get ids from names*/
@@ -64,7 +63,7 @@ struct _CamelMapiStorePrivate {
 
 	gboolean folders_synced; /* whether were synced folder list already */
 
-	GStaticRecMutex updates_lock;
+	GRecMutex updates_lock;
 	GCancellable *updates_cancellable; /* cancelled on dispose or disconnect */
 	GSList *update_folder_names; /* gchar *foldername */
 	guint update_folder_id;
@@ -197,17 +196,9 @@ cms_peek_folder_store (CamelMapiStore *mapi_store,
 static gboolean
 check_for_connection (CamelService *service, GError **error)
 {
-	CamelMapiStore *mapi_store = CAMEL_MAPI_STORE (service);
-	gboolean connected;
+	CamelMapiStore *store = CAMEL_MAPI_STORE (service);
 
-	if (!mapi_store)
-		return FALSE;
-
-	g_static_rec_mutex_lock (&mapi_store->priv->connection_lock);
-	connected = mapi_store->priv->connection && e_mapi_connection_connected (mapi_store->priv->connection);
-	g_static_rec_mutex_unlock (&mapi_store->priv->connection_lock);
-
-	return connected;
+	return store && store->priv->conn && e_mapi_connection_connected (store->priv->conn);
 }
 
 /* escapes backslashes with \5C and forward slashes with \2F */
@@ -483,7 +474,6 @@ mapi_folders_sync (CamelMapiStore *store, guint32 flags, GCancellable *cancellab
 	guint32 count, i;
 	GHashTable *old_cache_folders;
 	GError *err = NULL;
-	EMapiConnection *conn;
 
 	if (!camel_mapi_store_connected (store, cancellable, NULL)) {
 		g_set_error_literal (
@@ -492,17 +482,12 @@ mapi_folders_sync (CamelMapiStore *store, guint32 flags, GCancellable *cancellab
 		return FALSE;
 	}
 
-	conn = camel_mapi_store_ref_connection (store, cancellable, error);
-	if (!conn)
-		return FALSE;
-
-	status = e_mapi_connection_get_folders_list (conn, &folder_list, camel_mapi_update_operation_progress_cb, NULL, cancellable, &err);
+	status = e_mapi_connection_get_folders_list (priv->conn, &folder_list, camel_mapi_update_operation_progress_cb, NULL, cancellable, &err);
 	if (!status) {
 		camel_mapi_store_maybe_disconnect (store, err);
 
 		g_warning ("Could not get folder list (%s)\n", err ? err->message : "Unknown error");
 		g_clear_error (&err);
-		g_object_unref (conn);
 		return TRUE;
 	}
 
@@ -531,7 +516,7 @@ mapi_folders_sync (CamelMapiStore *store, guint32 flags, GCancellable *cancellab
 		GError *err = NULL;
 
 		/*Consult the name <-> fid hash table for a FID.*/
-		status = e_mapi_connection_get_pf_folders_list (conn, &folder_list, camel_mapi_update_operation_progress_cb, NULL, cancellable, &err);
+		status = e_mapi_connection_get_pf_folders_list (priv->conn, &folder_list, camel_mapi_update_operation_progress_cb, NULL, cancellable, &err);
 		if (!status)
 			g_warning ("Could not get Public folder list (%s)\n", err ? err->message : "Unknown error");
 
@@ -661,7 +646,6 @@ mapi_folders_sync (CamelMapiStore *store, guint32 flags, GCancellable *cancellab
 	g_slist_free (list);
 
 	priv->folders_synced = TRUE;
-	g_object_unref (conn);
 
 	return TRUE;
 }
@@ -981,7 +965,7 @@ stop_pending_updates (CamelMapiStore *mapi_store)
 
 	priv = mapi_store->priv;
 
-	g_static_rec_mutex_lock (&priv->updates_lock);
+	g_rec_mutex_lock (&priv->updates_lock);
 	if (priv->updates_cancellable) {
 		g_cancellable_cancel (priv->updates_cancellable);
 		g_object_unref (priv->updates_cancellable);
@@ -1003,7 +987,7 @@ stop_pending_updates (CamelMapiStore *mapi_store)
 		priv->update_folder_list_id = 0;
 	}
 
-	g_static_rec_mutex_unlock (&priv->updates_lock);
+	g_rec_mutex_unlock (&priv->updates_lock);
 }
 
 static void
@@ -1023,14 +1007,12 @@ mapi_store_dispose (GObject *object)
 		mapi_store->summary = NULL;
 	}
 
-	g_static_rec_mutex_lock (&mapi_store->priv->connection_lock);
-	if (priv->connection != NULL) {
-		g_signal_handlers_disconnect_by_func (priv->connection, camel_mapi_store_server_notification_cb, object);
+	if (priv->conn != NULL) {
+		g_signal_handlers_disconnect_by_func (priv->conn, camel_mapi_store_server_notification_cb, object);
 
-		g_object_unref (priv->connection);
-		priv->connection = NULL;
+		g_object_unref (priv->conn);
+		priv->conn = NULL;
 	}
-	g_static_rec_mutex_unlock (&mapi_store->priv->connection_lock);
 
 	/* Chain up to parent's dispose() method. */
 	G_OBJECT_CLASS (camel_mapi_store_parent_class)->dispose (object);
@@ -1057,8 +1039,7 @@ mapi_store_finalize (GObject *object)
 	if (priv->container_hash != NULL)
 		g_hash_table_destroy (priv->container_hash);
 
-	g_static_rec_mutex_free (&priv->connection_lock);
-	g_static_rec_mutex_free (&priv->updates_lock);
+	g_rec_mutex_clear (&priv->updates_lock);
 
 	/* Chain up to parent's finalize() method. */
 	G_OBJECT_CLASS (camel_mapi_store_parent_class)->finalize (object);
@@ -1325,15 +1306,10 @@ mapi_store_create_folder_sync (CamelStore *store,
 	e_mapi_util_mapi_id_from_string (parent_id, &parent_fid);
 	new_folder_id = 0;
 
-	conn = camel_mapi_store_ref_connection (mapi_store, cancellable, error);
-	if (!conn)
+	conn = priv->conn;
+	if (!cms_open_folder (mapi_store, conn, parent_fid, &obj_folder, cancellable, error))
 		return NULL;
 
-	if (!cms_open_folder (mapi_store, conn, parent_fid, &obj_folder, cancellable, error)) {
-		g_object_unref (conn);
-		return NULL;
-	}
-
 	if (!e_mapi_connection_create_folder (conn, &obj_folder, folder_name, IPF_NOTE, &new_folder_id, cancellable, &mapi_error))
 		new_folder_id = 0;
 	e_mapi_connection_close_folder (conn, &obj_folder, cancellable, &mapi_error);
@@ -1384,8 +1360,6 @@ mapi_store_create_folder_sync (CamelStore *store,
 		}
 	}
 
-	g_object_unref (conn);
-
 	return root;
 
 }
@@ -1399,7 +1373,6 @@ mapi_store_delete_folder_sync (CamelStore *store,
 	CamelMapiStore *mapi_store = CAMEL_MAPI_STORE (store);
 	CamelMapiStorePrivate  *priv = mapi_store->priv;
 	CamelMapiStoreInfo *msi;
-	EMapiConnection *conn;
 	mapi_object_t *obj_store = NULL;
 	const gchar *folder_id;
 	mapi_id_t folder_fid;
@@ -1438,10 +1411,6 @@ mapi_store_delete_folder_sync (CamelStore *store,
 
 	e_mapi_util_mapi_id_from_string (folder_id, &folder_fid);
 
-	conn = camel_mapi_store_ref_connection (mapi_store, cancellable, error);
-	if (!conn)
-		return FALSE;
-
 	msi = (CamelMapiStoreInfo *) camel_mapi_store_summary_get_folder_id (mapi_store->summary, folder_fid);
 	if (!msi ||
 	    (msi->mapi_folder_flags & CAMEL_MAPI_STORE_FOLDER_FLAG_PUBLIC) != 0 ||
@@ -1450,13 +1419,11 @@ mapi_store_delete_folder_sync (CamelStore *store,
 		   even when there are folder delete permissons on the folder
 		*/
 		status = TRUE;
-	} else if (cms_peek_folder_store (mapi_store, conn, folder_fid, &obj_store, cancellable, &local_error))
-		status = e_mapi_connection_remove_folder (conn, obj_store, folder_fid, cancellable, &local_error);
+	} else if (cms_peek_folder_store (mapi_store, priv->conn, folder_fid, &obj_store, cancellable, &local_error))
+		status = e_mapi_connection_remove_folder (priv->conn, obj_store, folder_fid, cancellable, &local_error);
 	else
 		status = FALSE;
 
-	g_object_unref (conn);
-
 	if (status) {
 		success = mapi_forget_folder (mapi_store, folder_name, &local_error);
 
@@ -1503,7 +1470,6 @@ mapi_store_rename_folder_sync (CamelStore *store,
 {
 	CamelMapiStore *mapi_store = CAMEL_MAPI_STORE (store);
 	CamelMapiStorePrivate  *priv = mapi_store->priv;
-	EMapiConnection *conn;
 	CamelStoreInfo *si = NULL;
 	CamelService *service;
 	const gchar *user_cache_dir;
@@ -1586,28 +1552,18 @@ mapi_store_rename_folder_sync (CamelStore *store,
 		return FALSE;
 	}
 
-	conn = camel_mapi_store_ref_connection (mapi_store, cancellable, error);
-	if (!conn) {
-		g_free (old_parent);
-		g_free (new_parent);
-
-		return FALSE;
-	}
-
 	if (tmp == NULL || g_str_equal (old_parent, new_parent)) {
 		gchar *folder_id;
 		gboolean status = FALSE;
 		mapi_object_t obj_folder;
 
-		if (cms_open_folder (mapi_store, conn, old_fid, &obj_folder, cancellable, &local_error)) {
-			status = e_mapi_connection_rename_folder (conn, &obj_folder, tmp ? tmp : new_name, cancellable, &local_error);
-			e_mapi_connection_close_folder (conn, &obj_folder, cancellable, &local_error);
+		if (cms_open_folder (mapi_store, priv->conn, old_fid, &obj_folder, cancellable, &local_error)) {
+			status = e_mapi_connection_rename_folder (priv->conn, &obj_folder, tmp ? tmp : new_name, cancellable, &local_error);
+			e_mapi_connection_close_folder (priv->conn, &obj_folder, cancellable, &local_error);
 		}
 
 		/* renaming in the same folder, thus no MoveFolder necessary */
 		if (!status) {
-			g_object_unref (conn);
-
 			if (local_error) {
 				if (!e_mapi_utils_propagate_cancelled_error (local_error, error))
 					g_set_error (
@@ -1676,21 +1632,19 @@ mapi_store_rename_folder_sync (CamelStore *store,
 			   e_mapi_util_mapi_id_from_string (new_parent_fid_str, &new_parent_fid)) {
 				mapi_object_t src_obj_folder, src_parent_obj_folder, des_obj_folder;
 
-				if (cms_open_folder (mapi_store, conn, old_fid, &src_obj_folder, cancellable, &local_error)) {
-					if (cms_open_folder (mapi_store, conn, old_parent_fid, &src_parent_obj_folder, cancellable, &local_error)) {
-						if (cms_open_folder (mapi_store, conn, new_parent_fid, &des_obj_folder, cancellable, &local_error)) {
-							status = e_mapi_connection_move_folder (conn, &src_obj_folder, &src_parent_obj_folder, &des_obj_folder, tmp, cancellable, &local_error);
-							e_mapi_connection_close_folder (conn, &des_obj_folder, cancellable, &local_error);
+				if (cms_open_folder (mapi_store, priv->conn, old_fid, &src_obj_folder, cancellable, &local_error)) {
+					if (cms_open_folder (mapi_store, priv->conn, old_parent_fid, &src_parent_obj_folder, cancellable, &local_error)) {
+						if (cms_open_folder (mapi_store, priv->conn, new_parent_fid, &des_obj_folder, cancellable, &local_error)) {
+							status = e_mapi_connection_move_folder (priv->conn, &src_obj_folder, &src_parent_obj_folder, &des_obj_folder, tmp, cancellable, &local_error);
+							e_mapi_connection_close_folder (priv->conn, &des_obj_folder, cancellable, &local_error);
 						}
-						e_mapi_connection_close_folder (conn, &src_parent_obj_folder, cancellable, &local_error);
+						e_mapi_connection_close_folder (priv->conn, &src_parent_obj_folder, cancellable, &local_error);
 					}
-					e_mapi_connection_close_folder (conn, &src_obj_folder, cancellable, &local_error);
+					e_mapi_connection_close_folder (priv->conn, &src_obj_folder, cancellable, &local_error);
 				}
 			}
 
 			if (!status) {
-				g_object_unref (conn);
-
 				if (local_error) {
 					if (!e_mapi_utils_propagate_cancelled_error (local_error, error))
 						g_set_error (
@@ -1727,8 +1681,6 @@ mapi_store_rename_folder_sync (CamelStore *store,
 		g_free (folder_id);
 	}
 
-	g_object_unref (conn);
-
 	si = camel_store_summary_path (mapi_store->summary, old_name);
 	if (si) {
 		mapi_id_t new_parent_fid;
@@ -2081,8 +2033,7 @@ camel_mapi_store_init (CamelMapiStore *mapi_store)
 {
 	mapi_store->priv = G_TYPE_INSTANCE_GET_PRIVATE (mapi_store, CAMEL_TYPE_MAPI_STORE, CamelMapiStorePrivate);
 
-	g_static_rec_mutex_init (&mapi_store->priv->connection_lock);
-	g_static_rec_mutex_init (&mapi_store->priv->updates_lock);
+	g_rec_mutex_init (&mapi_store->priv->updates_lock);
 	mapi_store->priv->updates_cancellable = NULL;
 	mapi_store->priv->update_folder_names = NULL;
 	mapi_store->priv->update_folder_id = 0;
@@ -2169,7 +2120,6 @@ mapi_connect_sync (CamelService *service,
                    GError **error)
 {
 	CamelMapiStore *store = CAMEL_MAPI_STORE (service);
-	EMapiConnection *conn;
 	CamelServiceConnectionStatus status;
 	CamelSession *session;
 	CamelSettings *settings;
@@ -2214,14 +2164,11 @@ mapi_connect_sync (CamelService *service,
 
 	camel_store_summary_save (store->summary);
 
-	conn = camel_mapi_store_ref_connection (store, cancellable, error);
-	if (!conn) {
-		g_free (name);
+	if (e_mapi_connection_get_store_quotas (
+		store->priv->conn, NULL,
+		&current_size, &receive_quota, &send_quota,
+		cancellable, NULL)) {
 
-		return FALSE;
-	}
-
-	if (e_mapi_connection_get_store_quotas (conn, NULL, &current_size, &receive_quota, &send_quota, cancellable, NULL)) {
 		if (current_size != -1) {
 			gchar *msg = NULL;
 
@@ -2247,7 +2194,6 @@ mapi_connect_sync (CamelService *service,
 		}
 	}
 
-	g_object_unref (conn);
 	g_free (name);
 
 	return TRUE;
@@ -2263,18 +2209,16 @@ mapi_disconnect_sync (CamelService *service,
 
 	stop_pending_updates (store);
 
-	g_static_rec_mutex_lock (&store->priv->connection_lock);
-	if (store->priv->connection) {
-		g_signal_handlers_disconnect_by_func (store->priv->connection, camel_mapi_store_server_notification_cb, store);
-		e_mapi_connection_disable_notifications (store->priv->connection, NULL, cancellable, error);
+	if (store->priv->conn) {
+		g_signal_handlers_disconnect_by_func (store->priv->conn, camel_mapi_store_server_notification_cb, store);
+		e_mapi_connection_disable_notifications (store->priv->conn, NULL, cancellable, error);
 
 		/* Close the mapi subsystem */
-		e_mapi_connection_disconnect (store->priv->connection, clean, clean ? cancellable : NULL, error);
+		e_mapi_connection_disconnect (store->priv->conn, clean, clean ? cancellable : NULL, error);
 
-		g_object_unref (store->priv->connection);
-		store->priv->connection = NULL;
+		g_object_unref (store->priv->conn);
+		store->priv->conn = NULL;
 	}
-	g_static_rec_mutex_unlock (&store->priv->connection_lock);
 
 	store->priv->folders_synced = FALSE;
 
@@ -2345,6 +2289,7 @@ run_update_thread (CamelMapiStore *mapi_store,
 		   GSList *foldernames)
 {
 	struct ScheduleUpdateData *sud;
+	GThread *thread;
 
 	g_return_if_fail (mapi_store != NULL);
 	g_return_if_fail (cancellable != NULL);
@@ -2354,7 +2299,8 @@ run_update_thread (CamelMapiStore *mapi_store,
 	sud->cancellable = g_object_ref (cancellable);
 	sud->foldernames = foldernames;
 
-	g_thread_create (camel_mapi_folder_update_thread, sud, FALSE, NULL);
+	thread = g_thread_new (NULL, camel_mapi_folder_update_thread, sud);
+	g_thread_unref (thread);
 }
 
 static gboolean
@@ -2371,9 +2317,9 @@ folder_update_cb (gpointer user_data)
 	g_return_val_if_fail (sud->mapi_store != NULL, FALSE);
 	g_return_val_if_fail (sud->mapi_store->priv != NULL, FALSE);
 
-	g_static_rec_mutex_lock (&sud->mapi_store->priv->updates_lock);
+	g_rec_mutex_lock (&sud->mapi_store->priv->updates_lock);
 	if (sud->expected_id != sud->mapi_store->priv->update_folder_id) {
-		g_static_rec_mutex_unlock (&sud->mapi_store->priv->updates_lock);
+		g_rec_mutex_unlock (&sud->mapi_store->priv->updates_lock);
 		return FALSE;
 	}
 
@@ -2386,7 +2332,7 @@ folder_update_cb (gpointer user_data)
 	else
 		g_slist_free_full (foldernames, g_free);
 
-	g_static_rec_mutex_unlock (&sud->mapi_store->priv->updates_lock);
+	g_rec_mutex_unlock (&sud->mapi_store->priv->updates_lock);
 
 	return FALSE;
 }
@@ -2425,10 +2371,10 @@ schedule_folder_update (CamelMapiStore *mapi_store, mapi_id_t fid)
 	if (!foldername)
 		return;
 
-	g_static_rec_mutex_lock (&mapi_store->priv->updates_lock);
+	g_rec_mutex_lock (&mapi_store->priv->updates_lock);
 	if (!mapi_store->priv->updates_cancellable ||
 	    g_slist_find_custom (mapi_store->priv->update_folder_names, foldername, (GCompareFunc) g_ascii_strcasecmp) != 0) {
-		g_static_rec_mutex_unlock (&mapi_store->priv->updates_lock);
+		g_rec_mutex_unlock (&mapi_store->priv->updates_lock);
 		return;
 	}
 
@@ -2442,7 +2388,7 @@ schedule_folder_update (CamelMapiStore *mapi_store, mapi_id_t fid)
 	mapi_store->priv->update_folder_id = g_timeout_add_seconds_full (G_PRIORITY_LOW, 5, folder_update_cb, sud, free_schedule_update_data);
 	sud->expected_id = mapi_store->priv->update_folder_id;
 
-	g_static_rec_mutex_unlock (&mapi_store->priv->updates_lock);
+	g_rec_mutex_unlock (&mapi_store->priv->updates_lock);
 }
 
 static gboolean
@@ -2458,9 +2404,9 @@ folder_list_update_cb (gpointer user_data)
 	g_return_val_if_fail (sud->mapi_store != NULL, FALSE);
 	g_return_val_if_fail (sud->mapi_store->priv != NULL, FALSE);
 
-	g_static_rec_mutex_lock (&sud->mapi_store->priv->updates_lock);
+	g_rec_mutex_lock (&sud->mapi_store->priv->updates_lock);
 	if (sud->expected_id != sud->mapi_store->priv->update_folder_list_id) {
-		g_static_rec_mutex_unlock (&sud->mapi_store->priv->updates_lock);
+		g_rec_mutex_unlock (&sud->mapi_store->priv->updates_lock);
 		return FALSE;
 	}
 
@@ -2470,7 +2416,7 @@ folder_list_update_cb (gpointer user_data)
 	if (!g_cancellable_is_cancelled (sud->cancellable))
 		run_update_thread (sud->mapi_store, sud->cancellable, NULL);
 
-	g_static_rec_mutex_unlock (&sud->mapi_store->priv->updates_lock);
+	g_rec_mutex_unlock (&sud->mapi_store->priv->updates_lock);
 
 	return FALSE;
 }
@@ -2483,9 +2429,9 @@ schedule_folder_list_update (CamelMapiStore *mapi_store)
 	g_return_if_fail (mapi_store != NULL);
 	g_return_if_fail (mapi_store->priv != NULL);
 
-	g_static_rec_mutex_lock (&mapi_store->priv->updates_lock);
+	g_rec_mutex_lock (&mapi_store->priv->updates_lock);
 	if (!mapi_store->priv->updates_cancellable) {
-		g_static_rec_mutex_unlock (&mapi_store->priv->updates_lock);
+		g_rec_mutex_unlock (&mapi_store->priv->updates_lock);
 		return;
 	}
 
@@ -2498,7 +2444,7 @@ schedule_folder_list_update (CamelMapiStore *mapi_store)
 	mapi_store->priv->update_folder_list_id = g_timeout_add_seconds_full (G_PRIORITY_LOW, 5, folder_list_update_cb, sud, free_schedule_update_data);
 	sud->expected_id = mapi_store->priv->update_folder_list_id;
 
-	g_static_rec_mutex_unlock (&mapi_store->priv->updates_lock);
+	g_rec_mutex_unlock (&mapi_store->priv->updates_lock);
 }
 
 static void
@@ -2658,25 +2604,30 @@ mapi_authenticate_sync (CamelService *service,
 	}
 
 	password_str = g_string_new (password);
-	g_static_rec_mutex_lock (&store->priv->connection_lock);
-	store->priv->connection = e_mapi_connection_new (
+	store->priv->conn = e_mapi_connection_new (
 		e_mail_session_get_registry (E_MAIL_SESSION (camel_service_get_session (service))),
 		profile, password_str, cancellable, &mapi_error);
 	g_string_free (password_str, TRUE);
-	if (store->priv->connection && e_mapi_connection_connected (store->priv->connection)) {
+	if (store->priv->conn && e_mapi_connection_connected (store->priv->conn)) {
 		result = CAMEL_AUTHENTICATION_ACCEPTED;
 
 		if (!store->priv->updates_cancellable)
 			store->priv->updates_cancellable = g_cancellable_new ();
 
-		g_signal_connect (store->priv->connection, "server-notification", G_CALLBACK (camel_mapi_store_server_notification_cb), store);
+		g_signal_connect (store->priv->conn, "server-notification", G_CALLBACK (camel_mapi_store_server_notification_cb), store);
 
 		if (camel_mapi_settings_get_listen_notifications (mapi_settings))
-			e_mapi_connection_enable_notifications (store->priv->connection, NULL, 0, NULL, NULL);
-	} else if (g_error_matches (mapi_error, E_MAPI_ERROR, MAPI_E_LOGON_FAILED) ||
-		   g_error_matches (mapi_error, E_MAPI_ERROR, MAPI_E_NETWORK_ERROR)) {
+			e_mapi_connection_enable_notifications (store->priv->conn, NULL, 0, NULL, NULL);
+	} else if (g_error_matches (mapi_error, E_MAPI_ERROR, MAPI_E_LOGON_FAILED)) {
 		g_clear_error (&mapi_error);
 		result = CAMEL_AUTHENTICATION_REJECTED;
+	} else if (g_error_matches (mapi_error, E_MAPI_ERROR, MAPI_E_NETWORK_ERROR)) {
+		g_set_error_literal (
+			error, CAMEL_SERVICE_ERROR,
+			CAMEL_SERVICE_ERROR_UNAVAILABLE,
+			mapi_error->message);
+		g_clear_error (&mapi_error);
+		result = CAMEL_AUTHENTICATION_ERROR;
 	} else {
 		/* mapi_error should be set */
 		g_return_val_if_fail (
@@ -2689,7 +2640,6 @@ mapi_authenticate_sync (CamelService *service,
 		result = CAMEL_AUTHENTICATION_ERROR;
 	}
 
-	g_static_rec_mutex_unlock (&store->priv->connection_lock);
 	g_object_unref (settings);
 
 	return result;
@@ -2771,12 +2721,8 @@ camel_mapi_store_maybe_disconnect (CamelMapiStore *mapi_store,
 	g_return_if_fail (CAMEL_IS_MAPI_STORE (mapi_store));
 
 	/* no error or already disconnected */
-	g_static_rec_mutex_lock (&mapi_store->priv->connection_lock);
-	if (!mapi_error || !mapi_store->priv->connection) {
-		g_static_rec_mutex_unlock (&mapi_store->priv->connection_lock);
+	if (!mapi_error || !mapi_store->priv->conn)
 		return;
-	}
-	g_static_rec_mutex_unlock (&mapi_store->priv->connection_lock);
 
 	if (g_error_matches (mapi_error, E_MAPI_ERROR, MAPI_E_NETWORK_ERROR) ||
 	    g_error_matches (mapi_error, E_MAPI_ERROR, MAPI_E_CALL_FAILED))
@@ -2914,26 +2860,18 @@ camel_mapi_store_folder_lookup (CamelMapiStore *mapi_store, const gchar *folder_
 }
 
 EMapiConnection *
-camel_mapi_store_ref_connection (CamelMapiStore *mapi_store,
+camel_mapi_store_get_connection (CamelMapiStore *mapi_store,
 				 GCancellable *cancellable,
 				 GError **error)
 {
-	EMapiConnection *conn;
-
 	g_return_val_if_fail (mapi_store != NULL, NULL);
 	g_return_val_if_fail (CAMEL_IS_MAPI_STORE (mapi_store), NULL);
 	g_return_val_if_fail (mapi_store->priv != NULL, NULL);
 
-	g_static_rec_mutex_lock (&mapi_store->priv->connection_lock);
-	if (!mapi_store->priv->connection)
+	if (!mapi_store->priv->conn)
 		camel_mapi_store_connected (mapi_store, cancellable, error);
 
-	conn = mapi_store->priv->connection;
-	if (conn)
-		g_object_ref (conn);
-	g_static_rec_mutex_unlock (&mapi_store->priv->connection_lock);
-
-	return conn;
+	return mapi_store->priv->conn;
 }
 
 /* ppath contains proposed path, this only makes sure that it's a unique path */
