@@ -202,20 +202,25 @@ e_mapi_config_utils_run_in_thread_with_feedback_general (GtkWindow *parent,
 	g_signal_connect (dialog, "response", G_CALLBACK (run_with_feedback_response_cb), rfd);
 
 	if (run_modal) {
+		GThread *thread;
 		GCancellable *cancellable;
 
 		cancellable = g_object_ref (rfd->cancellable);
 
-		g_return_if_fail (g_thread_create (run_with_feedback_thread, rfd, FALSE, NULL));
+		thread = g_thread_new (NULL, run_with_feedback_thread, rfd);
+		g_thread_unref (thread);
 
 		gtk_dialog_run (GTK_DIALOG (dialog));
 
 		g_cancellable_cancel (cancellable);
 		g_object_unref (cancellable);
 	} else {
+		GThread *thread;
+
 		gtk_widget_show (dialog);
 
-		g_return_if_fail (g_thread_create (run_with_feedback_thread, rfd, FALSE, NULL));
+		thread = g_thread_new (NULL, run_with_feedback_thread, rfd);
+		g_thread_unref (thread);
 	}
 }
 
@@ -545,6 +550,7 @@ e_mapi_config_utils_run_folder_size_dialog (ESourceRegistry *registry,
 	GtkWidget *spinner, *alignment, *dialog;
 	GtkWidget *spinner_label;
 	GCancellable *cancellable;
+	GThread *thread;
 	FolderSizeDialogData *fsd;
 
 	g_return_if_fail (mapi_settings != NULL);
@@ -587,7 +593,8 @@ e_mapi_config_utils_run_folder_size_dialog (ESourceRegistry *registry,
 	fsd->mapi_settings = g_object_ref (mapi_settings);
 	fsd->cancellable = g_object_ref (cancellable);
 
-	g_return_if_fail (g_thread_create (mapi_settings_get_folder_size_thread, fsd, FALSE, NULL));
+	thread = g_thread_new (NULL, mapi_settings_get_folder_size_thread, fsd);
+	g_thread_unref (thread);
 
 	/* Start the dialog */
 	gtk_dialog_run (GTK_DIALOG (dialog));
