@@ -331,7 +331,7 @@ e_mapi_util_find_array_proptag (struct mapi_SPropValue_array *properties, uint32
 		}
 	}
 
-	return 0;
+	return proptag;
 }
 
 enum MAPISTATUS
@@ -841,24 +841,6 @@ e_mapi_util_trigger_krb_auth (const EMapiProfileData *empd,
 	return success && !local_error;
 }
 
-gboolean
-e_mapi_util_trigger_krb_auth_from_settings (CamelMapiSettings *mapi_settings,
-					    GError **error)
-{
-	EMapiProfileData empd = { 0 };
-	CamelNetworkSettings *network_settings;
-
-	g_return_val_if_fail (CAMEL_IS_MAPI_SETTINGS (mapi_settings), FALSE);
-
-	network_settings = CAMEL_NETWORK_SETTINGS (mapi_settings);
-
-	empd.server = camel_network_settings_get_host (network_settings);
-	empd.username = camel_network_settings_get_user (network_settings);
-
-	e_mapi_util_profiledata_from_settings (&empd, mapi_settings);
-
-	return e_mapi_util_trigger_krb_auth (&empd, error);
-}
 
 /**
  * e_mapi_util_profile_name:
@@ -1135,13 +1117,6 @@ e_mapi_utils_create_mapi_context (struct mapi_context **mapi_ctx, GError **perro
 
 	g_free (profpath);
 
-	/* Initialize libmapi logger */
-	if (*mapi_ctx && g_getenv ("LIBMAPI_DEBUG")) {
-		guint32 debug_log_level = atoi (g_getenv ("LIBMAPI_DEBUG"));
-		SetMAPIDumpData (*mapi_ctx, TRUE);
-		SetMAPIDebugLevel (*mapi_ctx, debug_log_level);
-	}
-
 	e_mapi_utils_global_unlock ();
 
 	return TRUE;
@@ -1397,6 +1372,7 @@ unref_object_in_thread (gpointer ptr)
 void
 e_mapi_utils_unref_in_thread (GObject *object)
 {
+	GThread *thread;
 	GError *error = NULL;
 
 	if (!object)
@@ -1404,7 +1380,10 @@ e_mapi_utils_unref_in_thread (GObject *object)
 
 	g_return_if_fail (G_IS_OBJECT (object));
 
-	if (!g_thread_create (unref_object_in_thread, object, FALSE, &error)) {
+	thread = g_thread_try_new (NULL, unref_object_in_thread, object, &error);
+	if (thread) {
+		g_thread_unref (thread);
+	} else {
 		g_warning ("%s: Failed to run thread: %s", G_STRFUNC, error ? error->message : "Unknown error");
 		g_object_unref (object);
 	}
